@@ -1,3 +1,5 @@
+import struct
+
 from .plans import generate_deserializing_plans
 from .types import RecursiveType, LITTLE_ENDIAN
 from .writer import Writer
@@ -17,3 +19,6 @@ class Serializer:
         plans = generate_deserializing_plans(value_type_, first=first, last=last)
         for plan in plans:
             plan.write_using_plan(self, value, parent_custom_type=value_type_)
+
+    def write_simple_type(self, type, value):
+        self.writer.write_bytes(struct.pack(self.endianness + type.get_STRUCT_PATTERN(), value))
